@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0107';
 
 use Encode qw(encode_utf8);
 use Crypt::Passphrase::Bcrypt ();
@@ -17,7 +17,9 @@ sub make_encode_sub {
   my $cost = _get_cost($args->{cost});
 
   my $passphrase = Crypt::Passphrase::Bcrypt->new(
-    cost => $cost,
+    cost    => $cost,
+    hash    => $args->{hash} || 'sha256',
+    subtype => $args->{subtype},
   );
 
   return sub {
@@ -32,7 +34,9 @@ sub make_check_sub {
   my $cost = _get_cost($args->{cost});
 
   my $passphrase = Crypt::Passphrase::Bcrypt->new(
-    cost => $cost,
+    cost    => $cost,
+    hash    => $args->{hash} || 'sha256',
+    subtype => $args->{subtype},
   );
 
   return sub {
@@ -67,7 +71,7 @@ DBIx::Class::EncodedColumn::Crypt::Passphrase::Bcrypt - Crypt::Passphrase::Bcryp
 
 =head1 VERSION
 
-version 0.0106
+version 0.0107
 
 =head1 SYNOPSIS
 
@@ -120,7 +124,7 @@ Return a coderef that, when given a resultset object and a plain text value, wil
 return a boolean if the plain text matches the encoded value. This is typically
 used for password authentication.
 
-  $result->check_password($pass);
+  $authed = $result->check_password($pass);
 
 =head1 SEE ALSO
 
